#include "widget.h"
#include "ui_widget.h"
#include <QStringList>
#include <QDebug>
#include <QProcess>
#include <math.h>
#include <inttypes.h>
#include <QMessageBox>
#include <QFileDialog>

#define SEQUENCEMENT

//___________________________________________________________________________________________________
//                                              Constructeur
Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget)
{
    ui->setupUi(this);

    // les canaux d'accés à la carte son
    audioInput = NULL;
    inputDevice = NULL;


    // les paramètres de numérisation
    QList<QAudioDeviceInfo> availableDevices = QAudioDeviceInfo::availableDevices ( QAudio::AudioInput );
    for (int i=0 ; i<availableDevices.size() ; i++)
        ui->comboBoxDevice->addItem(availableDevices[i].deviceName());

    // si au moins une carte présente
    if (availableDevices.size()){
        info = QAudioDeviceInfo::defaultInputDevice();
        }

    // le buffer d'acquisition sur la carte son
    dataSound = new unsigned char [SOUND_BUFFER_SIZE];

    // l'IHM
    this->setWindowTitle("Sound samples acquisition - 1.00");
    }


//_________________________________________________________________________________________________
Widget::~Widget()
{
    delete ui;
    if (audioInput) {
                    audioInput->stop();
                    delete audioInput;
                    }
    if (dataSound) delete dataSound;
}


//_________________________________________________________________________________________________
//          bouton d' ACQUISITION DU SON
void Widget::on_toolButton_Record_Stop_clicked()
{


//     get the format from UI
if (!info.isFormatSupported(format)) {
   format = info.nearestFormat(format);
   }

// pour notre appli:
format.setSampleRate(8000);                        // echantillons par seconde
format.setChannelCount(1);                          // mono, une seule voie
format.setSampleSize(16);                           // deux octets par échantillon
format.setByteOrder(QAudioFormat::LittleEndian);


// audio input and inputDevice
if (audioInput)delete audioInput;                // le canal son de la carte
audioInput = new QAudioInput(format, this);      // création de l'entrée audio
audioInput->setBufferSize(SOUND_BUFFER_SIZE);          // taille du buffer
audioInput->setNotifyInterval(1);
audioInput->setVolume(1);

// lancement de l'acquisition
connect(inputDevice, SIGNAL(readyRead()), this, SLOT(data2Read()));
inputDevice = audioInput->start();
connect(inputDevice, SIGNAL(readyRead()), this, SLOT(data2Read()));

}

//___________________________________ slots activé quand des échantillons
//                                    sont prêts à être lus sur la carte son
void Widget::data2Read(){
     // le buffer de la carte son
    int count = inputDevice->read((char *)dataSound, SOUND_BUFFER_SIZE);
// structure du buffer
//    data[] : [Octets du Sample 1 du Canal 1] [Octets du Sample 1 du Canal 2]
//             [Octets du Sample 2 du Canal 1] [Octets du Sample 2 du Canal 2] ...

    u_int16_t *sample = (u_int16_t *)dataSound;
    qDebug()<<count<<" bytes read:";
    for (int i=0 ; i<count/2 ; i++)printf("%04d ", sample[i]);

}


//________________________________________________________________________________________________
void Widget::stateChanged(QAudio::State state){
    qDebug()<<"state:"<<state;
}


